Removed hidden args and hipLaunchParm from HIP/HCC path

[ROCm/hip-tests commit: bd985285df]
Este commit está contenido en:
Rahul Garg
2018-03-16 22:50:25 +05:30
padre d96395e02b
commit eb77a001da
Se han modificado 2 ficheros con 1 adiciones y 2 borrados
@@ -23,7 +23,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern texture<float, 2, hipReadModeElementType> tex;
extern "C" __global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
outputData[y * width + x] = tex2D(tex, x, y);